PALM-meteo: palmmeteo_stdplugins.plot.PlotPlugin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.plot.PlotPlugin Class Reference
Inheritance diagram for palmmeteo_stdplugins.plot.PlotPlugin:
[legend]
Collaboration diagram for palmmeteo_stdplugins.plot.PlotPlugin:
[legend]

## Public Member Functions
| __init__ (self)
| write_data (self, fout, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
| check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Public Attributes
| cm_default
| cm_zbased
| cm_wdir

## Detailed Description

    A plugin for plotting time series of vertical profiles of various
    meteorological quantities from the inputs to the dynamic driver.

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo_stdplugins.plot.PlotPlugin.__init__ | ( |  | self | ) |

## Member Function Documentation

## ◆ write_data()

palmmeteo_stdplugins.plot.PlotPlugin.write_data | ( |  | self,
|  |  | fout,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Loads data from the vertical interpolation step (where there are still
    full 3D fields for all timesteps, not just the boundaries) and plots
    them as configured.

Reimplemented from palmmeteo.plugins.WritePluginMixin.

## Member Data Documentation

## ◆ cm_default

palmmeteo_stdplugins.plot.PlotPlugin.cm_default

## ◆ cm_wdir

palmmeteo_stdplugins.plot.PlotPlugin.cm_wdir

## ◆ cm_zbased

palmmeteo_stdplugins.plot.PlotPlugin.cm_zbased

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/plot.py